@@ -24,7 +24,7 @@
 
     GPUTools
     ========
-    version : 4.3.10\n
+    version : 4.3.11\n
     author : Shervin Badanara\n
     author github : https://www.github.com/shervinbdndev/\n
     source github : https://www.github.com/shervinbdndev/PyScriptTools.py/
@@ -33,19 +33,18 @@
 
 
 try:
-    import GPUtil
     import colorama
     from typing import Type
     from typing_extensions import Self
     
     from ...exceptions import *
+    from ...utils import GPUUtils
 
-except:
-    raise ModuleNotFoundError
+except ModuleNotFoundError.__doc__ as mnfe:
+    raise AttributeError(args='Cannot Run') from None
 
 
-class GPUTools:
-    gpuInfo = GPUtil.getGPUs()
+class GPUTools(GPUUtils):
 
     @classmethod
     def ShowGPU_ID(cls : Type[Self] , show : bool = False) -> str:
